# Textual-Color-O-Matic Changelog

## 0.1.3 (2025-06-15)

- Added width and height attributes to the Updated message for more compatibility with Textual-Pyfiglet

## 0.1.0 (2025-06-15)

- First alpha release
